==> scheduling-base-2.4.1-sources.jar: org/smallmind/scheduling/base/ProxyJob.java <==
/*
 * Copyright (c) 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016 David Berkman
 * 
 * This file is part of the SmallMind Code Project.
 * 
 * The SmallMind Code Project is free software, you can redistribute
 * it and/or modify it under either, at your discretion...
 * 
 * 1) The terms of GNU Affero General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or (at
 * your option) any later version.
 * 
 * ...or...
 * 
 * 2) The terms of the Apache License, Version 2.0.
 * 
 * The SmallMind Code Project is distributed in the hope that it will
 * be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License or Apache License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * and the Apache License along with the SmallMind Code Project. If not, see
 * <http://www.gnu.org/licenses/> or <http://www.apache.org/licenses/LICENSE-2.0>.
 * 
 * Additional permission under the GNU Affero GPL version 3 section 7
 * ------------------------------------------------------------------
 * If you modify this Program, or any covered work, by linking or
 * combining it with other code, such other code is not for that reason
 * alone subject to any of the requirements of the GNU Affero GPL
 * version 3.
 */
package org.smallmind.scheduling.base;

import java.util.Date;

public interface ProxyJob {

  public abstract boolean logOnZeroCount ();

  public abstract JobStatus getJobStatus ();

  public abstract int getCount ();

  public abstract void incCount ();

  public abstract Date getStartTime ();

  public abstract Date getStopTime ();

  public abstract Throwable[] getThrowables ();

  public abstract void setThrowable (Throwable throwable);

  public abstract void proceed ()
    throws Exception;

  public abstract void cleanup ()
    throws Exception;
}

==> scheduling-base-2.4.12-sources.jar: org/smallmind/scheduling/base/ProxyJob.java <==
/*
 * Copyright (c) 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016 David Berkman
 * 
 * This file is part of the SmallMind Code Project.
 * 
 * The SmallMind Code Project is free software, you can redistribute
 * it and/or modify it under either, at your discretion...
 * 
 * 1) The terms of GNU Affero General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or (at
 * your option) any later version.
 * 
 * ...or...
 * 
 * 2) The terms of the Apache License, Version 2.0.
 * 
 * The SmallMind Code Project is distributed in the hope that it will
 * be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License or Apache License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * and the Apache License along with the SmallMind Code Project. If not, see
 * <http://www.gnu.org/licenses/> or <http://www.apache.org/licenses/LICENSE-2.0>.
 * 
 * Additional permission under the GNU Affero GPL version 3 section 7
 * ------------------------------------------------------------------
 * If you modify this Program, or any covered work, by linking or
 * combining it with other code, such other code is not for that reason
 * alone subject to any of the requirements of the GNU Affero GPL
 * version 3.
 */
package org.smallmind.scheduling.base;

import java.util.Date;
import org.smallmind.nutsnbolts.util.SuccessOrFailure;

public interface ProxyJob {

  public abstract boolean logOnZeroCount ();

  public abstract SuccessOrFailure getJobStatus ();

  public abstract int getCount ();

  public abstract void incCount ();

  public abstract Date getStartTime ();

  public abstract Date getStopTime ();

  public abstract Throwable[] getThrowables ();

  public abstract void setThrowable (Throwable throwable);

  public abstract void proceed ()
    throws Exception;

  public abstract void cleanup ()
    throws Exception;
}
